summaryrefslogtreecommitdiffstats
path: root/include/camera/ICamera.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/camera/ICamera.h')
-rw-r--r--include/camera/ICamera.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/camera/ICamera.h b/include/camera/ICamera.h
index 3d18837..eccaa41 100644
--- a/include/camera/ICamera.h
+++ b/include/camera/ICamera.h
@@ -27,7 +27,7 @@
namespace android {
class ICameraClient;
-class ISurfaceTexture;
+class IGraphicBufferProducer;
class Surface;
class ICamera: public IInterface
@@ -49,9 +49,9 @@ public:
// pass the buffered Surface to the camera service
virtual status_t setPreviewDisplay(const sp<Surface>& surface) = 0;
// pass the buffered ISurfaceTexture to the camera service
virtual status_t setPreviewTexture(
- const sp<ISurfaceTexture>& surfaceTexture) = 0;
+ const sp<IGraphicBufferProducer>& bufferProducer) = 0;
// set the preview callback flag to affect how the received frames from
// preview are handled.
@@ -49,9 +49,9 @@ public:
// pass the buffered Surface to the camera service
virtual status_t setPreviewDisplay(const sp<Surface>& surface) = 0;
- // pass the buffered ISurfaceTexture to the camera service
+ // pass the buffered IGraphicBufferProducer to the camera service
virtual status_t setPreviewTexture(